# NOTE: There is no check script because:
# (1) The tests try to access the Atlas over the Internet, which fails on the
#     koji builders; and
# (2) The tests want the data directories to be writable so that updates to
#     this package can be installed.  But we want to use RPM to manage updates,
#     so unwritable data directories are correct.
#
# The maintainer should manually run the tests before each update.

%global upstreamver 1r5p0
%global pkgname atlasrep

Name:           gap-pkg-%{pkgname}
Version:        %(sed -r "s/r|p/./g" <<< %upstreamver)
Release:        4%{?dist}
Summary:        GAP interface to the Atlas of Group Representations

License:        GPLv3+
URL:            http://www.math.rwth-aachen.de/~Thomas.Breuer/%{pkgname}/
Source0:        http://www.math.rwth-aachen.de/~Thomas.Breuer/%{pkgname}/%{pkgname}%{upstreamver}.tar.gz
Source1:        http://www.math.rwth-aachen.de/~Thomas.Breuer/%{pkgname}/%{pkgname}data.tar.gz
BuildArch:      noarch

BuildRequires:  gap-devel
BuildRequires:  gap-pkg-browse
BuildRequires:  gap-pkg-ctbllib

Requires:       coreutils
Requires:       gap-pkg-io

Recommends:     gap-pkg-browse
Recommends:     gap-pkg-ctbllib
Recommends:     gap-pkg-tomlib

Suggests:       meataxe

%description
The aim of the AtlasRep package is to provide an interface between GAP
and the Atlas of Group Representations, a database that comprises
representations of many almost simple groups and information about their
maximal subgroups.  This database is available independent of GAP.

The AtlasRep package consists of this database and a GAP interface.  The
latter allows the user to get an overview of the database, and to access
the data in GAP format.

%prep
%setup -q -n %{pkgname}
%setup -q -T -D -b 1 -n %{pkgname}

# Fix encodings
for fil in doc/{atlasrep,extend,interfac,main,technica,tutorial,utils}.xml \
  doc/manual.css gap/access.gd gap/mindeg.g{d,i}; do
  iconv -f iso8859-1 -t utf8 $fil > $fil.utf8
  touch -r $fil $fil.utf8
  mv -f $fil.utf8 $fil
done

# Fix bibliographic reference to GAP
sed -i.orig 's/GAP4412/GAP449/' doc/introduc.xml
touch -r doc/introduc.xml.orig doc/introduc
rm -f doc/introduc.xml.orig

%build
# Link to main GAP documentation
cp -a %{_gap_dir}/doc ../../doc
mkdir -p ../pkg
ln -s ../%{pkgname} ../pkg
cp -a %{_gap_dir}/pkg/ctbllib ..
gap -l "$PWD/..;%{_gap_dir}" << EOF
MakeGAPDocDoc( "doc", "main",
  ["../gap/access.gd", "../gap/access.gi", "../gap/bbox.gd",
   "../gap/brmindeg.g", "../gap/brspor.g", "../gap/interfac.gd",
   "../gap/interfac.gi", "../gap/mindeg.gd", "../gap/scanmtx.gd",
   "../gap/test.g", "../gap/types.g", "../gap/types.gd", "../gap/utils.gd",
   "../tst/testinst.g"],
  "AtlasRep", "../../..", "MathJax" );
CopyHTMLStyleFiles( "doc" );
GAPDocManualLab( "AtlasRep" );
EOF
rm -fr ../../doc ../{ctbllib,pkg}

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../%{pkgname} %{buildroot}%{_gap_dir}/pkg
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/README
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/datagens/dummy
rm -fr %{buildroot}%{_gap_dir}/pkg/%{pkgname}/dataword/{dummy,CVS,.cvsignore}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/*.{aux,bbl,blg,brf,idx,ilg,ind,log,out,pnr,toc}

%files
%doc README
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Wed Nov 11 2015 Jerry James <loganjerry@gmail.com> - 1.5.0-4
- Drop scriptlets; gap-core now uses rpm file triggers
- Rebuild documentation from source

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jan 23 2015 Jerry James <loganjerry@gmail.com> - 1.5.0-2
- Add Requires(post) and Requires(postun)
- Mark documentation as such

* Fri Jan 16 2015 Jerry James <loganjerry@gmail.com> - 1.5.0-1
- Initial RPM
